@@ -13,9 +13,9 @@ use super::{
         OptI64Column, OptI8Column, OptTimeColumn, OptTimestampColumn, OptU8Column,
     },
     columnar::{ColumnBuffer, ColumnProjections},
-    BinColumn, BinColumnIt, BinColumnWriter, BufferDescription, BufferKind, CharColumn,
-    ColumnarBuffer, NullableSlice, NullableSliceMut, TextColumn, TextColumnIt, TextColumnWriter,
-    WCharColumn,
+    BinColumn, BinColumnView, BinColumnWriter, BufferDescription, BufferKind, CharColumn,
+    ColumnarBuffer, Item, NullableSlice, NullableSliceMut, TextColumn, TextColumnView,
+    TextColumnWriter, WCharColumn,
 };
 
 /// Since buffer shapes are same for all time / timestamps independent of the precision and we do
@@ -313,13 +313,13 @@ pub fn buffer_from_description_and_indices(
 /// For columns of fixed size types, which are guaranteed to not contain null, a direct access to
 /// the slice is offered. Buffers over nullable columns can be accessed via an iterator over
 /// options.
-#[derive(Debug)]
+#[derive(Debug, Clone, Copy)]
 pub enum AnyColumnView<'a> {
     /// Nullable character data in the system encoding.
-    Text(TextColumnIt<'a, u8>),
+    Text(TextColumnView<'a, u8>),
     /// Nullable character data encoded in UTF-16.
-    WText(TextColumnIt<'a, u16>),
-    Binary(BinColumnIt<'a>),
+    WText(TextColumnView<'a, u16>),
+    Binary(BinColumnView<'a>),
     Date(&'a [Date]),
     Time(&'a [Time]),
     Timestamp(&'a [Timestamp]),
@@ -344,6 +344,48 @@ pub enum AnyColumnView<'a> {
     NullableBit(NullableSlice<'a, Bit>),
 }
 
+impl<'a> AnyColumnView<'a> {
+    /// This method is useful if you expect the variant to be [`AnyColumnView::Text`]. It allows you
+    /// to unwrap the inner column view without explictly matching it.
+    pub fn as_text_view(self) -> Option<TextColumnView<'a, u8>> {
+        if let Self::Text(view) = self {
+            Some(view)
+        } else {
+            None
+        }
+    }
+
+    /// This method is useful if you expect the variant to be [`AnyColumnView::WText`]. It allows
+    /// you to unwrap the inner column view without explictly matching it.
+    pub fn as_w_text_view(self) -> Option<TextColumnView<'a, u16>> {
+        if let Self::WText(view) = self {
+            Some(view)
+        } else {
+            None
+        }
+    }
+
+    /// This method is useful if you expect the variant to be [`AnyColumnView::Binary`]. It allows
+    /// you to unwrap the inner column view without explictly matching it.
+    pub fn as_bin_view(self) -> Option<BinColumnView<'a>> {
+        if let Self::Binary(view) = self {
+            Some(view)
+        } else {
+            None
+        }
+    }
+
+    /// Extract the array type from an [`AnyColumnView`].
+    pub fn as_slice<I: Item>(self) -> Option<&'a [I]> {
+        I::as_slice(self)
+    }
+
+    /// Extract the typed nullable buffer from an [`AnyColumnView`].
+    pub fn as_nullable_slice<I: Item>(self) -> Option<NullableSlice<'a, I>> {
+        I::as_nullable_slice(self)
+    }
+}
+
 /// A mutable borrowed view on the valid rows in a column of a [`ColumnarBuffer`].
 ///
 /// For columns of fixed size types, which are guaranteed to not contain null, a direct access to
@@ -417,11 +459,11 @@ unsafe impl ColumnBuffer for AnyColumnBuffer {
         }
     }
 
-    unsafe fn view(&self, valid_rows: usize) -> AnyColumnView {
+    fn view(&self, valid_rows: usize) -> AnyColumnView {
         match self {
-            AnyColumnBuffer::Binary(col) => AnyColumnView::Binary(col.iter(valid_rows)),
-            AnyColumnBuffer::Text(col) => AnyColumnView::Text(col.iter(valid_rows)),
-            AnyColumnBuffer::WText(col) => AnyColumnView::WText(col.iter(valid_rows)),
+            AnyColumnBuffer::Binary(col) => AnyColumnView::Binary(col.view(valid_rows)),
+            AnyColumnBuffer::Text(col) => AnyColumnView::Text(col.view(valid_rows)),
+            AnyColumnBuffer::WText(col) => AnyColumnView::WText(col.view(valid_rows)),
             AnyColumnBuffer::Date(col) => AnyColumnView::Date(&col[0..valid_rows]),
             AnyColumnBuffer::Time(col) => AnyColumnView::Time(&col[0..valid_rows]),
             AnyColumnBuffer::Timestamp(col) => AnyColumnView::Timestamp(&col[0..valid_rows]),
