@@ -7,7 +7,7 @@ use super::{ColumnBuffer, ColumnProjections, Indicator};
 
 use log::debug;
 use odbc_sys::{CDataType, NULL_DATA};
-use std::{cmp::min, ffi::c_void, mem::size_of};
+use std::{cmp::min, ffi::c_void, mem::size_of, panic};
 use widestring::U16Str;
 
 /// A column buffer for character data. The actual encoding used may depend on your system locale.
@@ -60,20 +60,10 @@ impl<C> TextColumn<C> {
     /// panic on accessing an undefined element. It will panic however if `row_index` is larger or
     /// equal to the maximum number of elements in the buffer.
     pub fn value_at(&self, row_index: usize) -> Option<&[C]> {
-        match self.indicator_at(row_index) {
-            Indicator::Null => None,
-            // Seen no total in the wild then binding shorter buffer to fixed sized CHAR in MSSQL.
-            Indicator::NoTotal => {
-                let offset = row_index * (self.max_str_len + 1);
-                Some(&self.values[offset..offset + self.max_str_len])
-            }
-            Indicator::Length(length_in_bytes) => {
-                let offset = row_index * (self.max_str_len + 1);
-                let length_in_chars = length_in_bytes / size_of::<C>();
-                let length = min(self.max_str_len, length_in_chars);
-                Some(&self.values[offset..offset + length])
-            }
-        }
+        self.content_length_at(row_index).map(|length| {
+            let offset = row_index * (self.max_str_len + 1);
+            &self.values[offset..offset + length]
+        })
     }
 
     /// Maximum length of elements
@@ -91,6 +81,24 @@ impl<C> TextColumn<C> {
         Indicator::from_isize(self.indicators[row_index])
     }
 
+    /// Length of value at the specified position. This is different from an indicator as it refers
+    /// to the length of the value in the buffer, not to the length of the value in the datasource.
+    /// The two things are different for truncated values.
+    pub fn content_length_at(&self, row_index: usize) -> Option<usize> {
+        match self.indicator_at(row_index) {
+            Indicator::Null => None,
+            // Seen no total in the wild then binding shorter buffer to fixed sized CHAR in MSSQL.
+            Indicator::NoTotal => {
+                Some(self.max_str_len)
+            }
+            Indicator::Length(length_in_bytes) => {
+                let length_in_chars = length_in_bytes / size_of::<C>();
+                let length = min(self.max_str_len, length_in_chars);
+                Some(length)
+            }
+        }
+    }
+
     /// Changes the maximum string length the buffer can hold. This operation is useful if you find
     /// an unexpected large input string during insertion.
     ///
@@ -195,23 +203,6 @@ impl<C> TextColumn<C> {
         }
     }
 
-    /// Iterator over the first `num_rows` values of a text column.
-    ///
-    /// # Safety
-    ///
-    /// Num rows may not exceed the actually amount of valid num_rows filled be the ODBC API. The
-    /// column buffer does not know how many elements were in the last row group, and therefore can
-    /// not guarantee the accessed element to be valid and in a defined state. It also can not panic
-    /// on accessing an undefined element. It will panic however if `row_index` is larger or equal
-    /// to the maximum number of elements in the buffer.
-    pub unsafe fn iter(&self, num_rows: usize) -> TextColumnIt<'_, C> {
-        TextColumnIt {
-            pos: 0,
-            num_rows,
-            col: self,
-        }
-    }
-
     /// Sets the value of the buffer at index at Null or the specified binary Text. This method will
     /// panic on out of bounds index, or if input holds a text which is larger than the maximum
     /// allowed element length. `input` must be specified without the terminating zero.
@@ -289,6 +280,18 @@ impl<C> TextColumn<C> {
             to: n,
         }
     }
+
+    /// Provides access to the raw underlying value buffer. Normal applications should have little
+    /// reason to call this method. Yet it may be useful for writing bindings which copy directly
+    /// from the ODBC in memory representation into other kinds of buffers.
+    /// 
+    /// The buffer contains the bytes for every non null valid element, padded to the maximum string
+    /// length. The content of the padding bytes is undefined. Usually ODBC drivers write a
+    /// terminating zero at the end of each string. For the actual value length call
+    /// [`Self::conten_length_at`]. Any element starts at index * ([`Self::max_len`] + 1).
+    pub fn raw_value_buffer(&self, num_valid_rows: usize) -> &[C] {
+        &self.values[..(self.max_str_len + 1) * num_valid_rows]
+    }
 }
 
 impl WCharColumn {
@@ -307,7 +310,7 @@ impl WCharColumn {
 }
 
 unsafe impl<'a, C: 'static> ColumnProjections<'a> for TextColumn<C> {
-    type View = TextColumnIt<'a, C>;
+    type View = TextColumnView<'a, C>;
 
     type ViewMut = TextColumnWriter<'a, C>;
 }
@@ -316,8 +319,11 @@ unsafe impl<C: 'static> ColumnBuffer for TextColumn<C>
 where
     TextColumn<C>: CDataMut + HasDataType,
 {
-    unsafe fn view(&self, valid_rows: usize) -> TextColumnIt<'_, C> {
-        self.iter(valid_rows)
+    fn view(&self, valid_rows: usize) -> TextColumnView<'_, C> {
+        TextColumnView {
+            num_rows: valid_rows,
+            col: self,
+        }
     }
 
     unsafe fn view_mut(&mut self, valid_rows: usize) -> TextColumnWriter<'_, C> {
@@ -334,7 +340,73 @@ where
     }
 }
 
-/// Iterator over a text column. See [`TextColumn::iter`]
+/// Allows read only access to the valid part of a text column.
+///
+/// You may ask, why is this type required, should we not just be able to use `&TextColumn`? The
+/// problem with `TextColumn` is, that it is a buffer, but it has no idea how many of its members
+/// are actually valid, and have been returned with the last row group of the the result set. That
+/// number is maintained on the level of the entire column buffer. So a text column knows the number
+/// of valid rows, in addition to holding a reference to the buffer, in order to guarantee, that
+/// every element acccessed through it, is valid.
+#[derive(Debug, Clone, Copy)]
+pub struct TextColumnView<'c, C> {
+    num_rows: usize,
+    col: &'c TextColumn<C>,
+}
+
+impl<'c, C> TextColumnView<'c, C> {
+    /// The number of valid elements in the text column.
+    pub fn len(&self) -> usize {
+        self.num_rows
+    }
+
+    /// True if, and only if there are no valid rows in the column buffer.
+    pub fn is_empty(&self) -> bool {
+        self.num_rows == 0
+    }
+
+    /// Slice of text at the specified row index without terminating zero.
+    pub fn get(&self, index: usize) -> Option<&'c [C]> {
+        self.col.value_at(index)
+    }
+
+    /// Iterator over the valid elements of the text buffer
+    pub fn iter(&self) -> TextColumnIt<'c, C> {
+        TextColumnIt {
+            pos: 0,
+            num_rows: self.num_rows,
+            col: self.col,
+        }
+    }
+
+    /// Length of value at the specified position. This is different from an indicator as it refers
+    /// to the length of the value in the buffer, not to the length of the value in the datasource.
+    /// The two things are different for truncated values.
+    pub fn content_length_at(&self, row_index: usize) -> Option<usize> {
+        if row_index >= self.num_rows {
+            panic!("Row index points beyond the range of valid values.")
+        }
+        self.col.content_length_at(row_index)
+    }
+
+    /// Provides access to the raw underlying value buffer. Normal applications should have little
+    /// reason to call this method. Yet it may be useful for writing bindings which copy directly
+    /// from the ODBC in memory representation into other kinds of buffers.
+    /// 
+    /// The buffer contains the bytes for every non null valid element, padded to the maximum string
+    /// length. The content of the padding bytes is undefined. Usually ODBC drivers write a
+    /// terminating zero at the end of each string. For the actual value length call
+    /// [`Self::conten_length_at`]. Any element starts at index * ([`Self::max_len`] + 1).
+    pub fn raw_value_buffer(&self) -> &'c [C] {
+        self.col.raw_value_buffer(self.num_rows)
+    }
+
+    pub fn max_len(&self) -> usize {
+        self.col.max_len()
+    }
+}
+
+/// Iterator over a text column. See [`TextColumnView::iter`]
 #[derive(Debug)]
 pub struct TextColumnIt<'c, C> {
     pos: usize,
